/* pcap.h: VMS pcap emulation network routines for SIMH
  ------------------------------------------------------------------------------
   Copyright (c) 2003-2004, Graham Burley

   Permission is hereby granted, free of charge, to any person obtaining a
   copy of this software and associated documentation files (the "Software"),
   to deal in the Software without restriction, including without limitation
   the rights to use, copy, modify, merge, publish, distribute, sublicense,
   and/or sell copies of the Software, and to permit persons to whom the
   Software is furnished to do so, subject to the following conditions:

   The above copyright notice and this permission notice shall be included in
   all copies or substantial portions of the Software.

   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
   THE AUTHOR BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
   IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
   CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

   Except as contained in this notice, the name of the author shall not be
   used in advertising or otherwise to promote the sale, use or other dealings
   in this Software without prior written authorization from the author.

  ------------------------------------------------------------------------------

  Modification history:

  06-Sep-04  GB   Added pcap_datalink req w/3.2-3
  13-Jan-04  GB   Added pcap_find(free)alldevs
  25-Oct-03  GB   Initial working version w/3.0-1

  ------------------------------------------------------------------------------
*/

#include <descrip.h>

#define PCAP_MAX_PORTS 8
#define PCAP_MAX_PACKET 1514

#define PCAP_ERRBUF_SIZE 80
#define PCAP_IF_LOOPBACK 0x00000001		/* interface is loopback */
#define DLT_EN10MB 1				/* datalink type */

typedef unsigned char u_char;
typedef unsigned int u_int;

struct pcap_iosb {
	short s;
	short len;
	int more;
};

struct pcap_dq {
	int len;
	int port[PCAP_MAX_PORTS];
};

struct pcap_port {
	int index;
	int efn;
	int chan;
	int pty;
	struct pcap_iosb io;
	struct pcap_dq *dq;
	u_char buf[PCAP_MAX_PACKET];
};

struct pcap {
	char *devnam;
	struct dsc$descriptor devnam_d;
	unsigned char pha[6];
	int ports;
	struct pcap_port port[PCAP_MAX_PORTS];
	struct pcap_dq dq;
};
typedef struct pcap pcap_t;

struct pcap_pkthdr {
	int len;
};

typedef void (*pcap_handler)(u_char *, const struct pcap_pkthdr *
	,const u_char *);

struct pcap_if {
	struct pcap_if *next;
	char *name;
	char *description;
	u_int flags;
};
typedef struct pcap_if pcap_if_t;

pcap_t *pcap_open_live(char *, int, int, int, char *);
void pcap_close(pcap_t *);
int pcap_sendpacket(pcap_t *, u_char *, int);
int pcap_dispatch(pcap_t *, int, pcap_handler, u_char *);
int pcap_findalldevs(pcap_if_t **, char *);
int pcap_freealldevs(pcap_if_t *);
int pcap_datalink(pcap_t *);
